package net.sf.lucis.core;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.search.highlight.Formatter;
import org.apache.lucene.search.highlight.SimpleHTMLFormatter;

import com.google.common.base.Preconditions;


/**
 * Highlighter configuration. 
 * @author Emilio Escobar Reyero
 */
public class Highlight implements Serializable {

	private static final long serialVersionUID = 2682965124967878782L;
	
	private final Map<String, Integer> fields;
	private final Analyzer analyzer;
	private final Formatter formatter;
	
	private Highlight(Analyzer analyzer, Formatter formatter, Map<String, Integer> fields) {
		this.analyzer = analyzer;
		this.formatter = formatter;
		this.fields = fields;
	}

	public static Highlight of(Analyzer analyzer, Formatter formatter, Map<String, Integer> fields) {
		Preconditions.checkNotNull(analyzer);
		Preconditions.checkNotNull(formatter);
		Preconditions.checkNotNull(fields);
		return new Highlight(analyzer, formatter, fields);
	}
	
	public static Highlight of(Map<String, Integer> fields) {
		Preconditions.checkNotNull(fields);
		return new Highlight(new StandardAnalyzer(), new SimpleHTMLFormatter(), fields);
	}
	
	public static Highlight no() {
		return new Highlight(new StandardAnalyzer(), new SimpleHTMLFormatter(), new HashMap<String, Integer>());
	}
	
	public Analyzer getAnalyzer() {
		return analyzer;
	}
	
	public Formatter getFormatter() {
		return formatter;
	}
	
	public Map<String, Integer> getFields() {
		return fields;
	}
	
}
