package net.sf.lucis.core.impl;

import java.io.IOException;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.apache.lucene.index.IndexReader;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.MultiSearcher;
import org.apache.lucene.search.Searcher;
import org.apache.lucene.store.Directory;

import net.sf.derquinse.lucis.IndexNotAvailableException;
import net.sf.lucis.core.DirectoryProvider;
import net.sf.lucis.core.LucisSearcher;


import com.google.common.base.Preconditions;
import com.google.common.base.Supplier;
import com.google.common.collect.ImmutableSet;

/**
 * MultiSearcher simple implementation. 
 * @author Emilio Escobar Reyero
 */
public abstract class MultiSearcherProvider implements Supplier<LucisSearcher> {
	
	public static MultiSearcherProvider of(final Collection<DirectoryProvider> providers) {
		Preconditions.checkNotNull(providers);
		return new MultiSearcherProvider() {
			@Override
			Collection<Directory> directories() {
				Collection<Directory> directories = new HashSet<Directory>();
				
				for (DirectoryProvider dp : providers) {
					directories.add(dp.getDirectory());
				}

				return ImmutableSet.copyOf(directories);
			}
		};
	}
	
	
	private MultiSearcherProvider() {
	}
	
	abstract Collection<Directory> directories();
	
	public LucisSearcher get() {
		try {
			
			Collection<Directory> dirs = directories();
			
			IndexSearcher[] searchers = new IndexSearcher[dirs.size()];
			int i = 0;
			for (Directory d : dirs) {
				final IndexReader reader = IndexReader.open(d, true);
				final IndexSearcher searcher = new IndexSearcher(reader);
				searchers[i] = searcher;
				i++;
			}
			return new MultipleSearcher(searchers);
		} catch (Exception e) {
			throw new IndexNotAvailableException(e);
		}
	}
	
	
	
	private static final class MultipleSearcher extends AbstractSearcher {
		private MultiSearcher searcher;

		private MultipleSearcher(final IndexSearcher[] searchers) {
			try {
				this.searcher = new MultiSearcher(searchers);
			} catch (IOException e) {
				this.searcher = null;
			}
		}
		
		@Override
		Searcher searcher() {
			return searcher;
		}

		public void close() {
			try {
				searcher.close();
			} catch (Exception e) {}
		}
	}
	
}
